@@ -251,8 +251,12 @@ class DSLibrary(object):
         open_args.pop("format", None)
         open_args.pop("format_options", None)
         open_args.pop("dask", None)
-        # send all outputs to mlflow if requested
-        use_mlflow = self._mlflow_all and ("w" in mode or "a" in mode)
+        # send all outputs to mlflow if requested, but only within a run - see start_run()
+        use_mlflow = self._mlflow_all and ("w" in mode or "a" in mode) and self._run_id
+        # TODO if the URI is obviously external (i.e. s3://...), or local (i.e. ./my_file), it doesn't make sense to
+        #   send it to mlflow
+        # if ":" in uri or uri.startswith("./"):
+        #    use_mlflow = False
         if use_mlflow:
             if "a" in mode:
                 raise DSLibraryException("Append mode not available with mlflow output")
@@ -528,8 +532,8 @@ class DSLibrary(object):
         """
         use_mlflow = self._mlflow_all
         if use_mlflow:
-            mlflow.start_run()
-            a_r = mlflow.active_run()
+            a_r = mlflow.start_run()
+            a_r = a_r or mlflow.active_run()
             self._run_id = a_r.info.run_id if a_r else None
         else:
             # generate a run ID
@@ -540,7 +544,7 @@ class DSLibrary(object):
                 from mlflow.entities import Run, RunData, RunInfo
                 self._mlflow_run = Run(
                     RunInfo(
-                        run_uuid=self._run_id, experiment_id=self._spec.get("uri"), user_id=self._spec.get("user"),
+                        run_uuid=self._run_id, experiment_id=self._spec.get("uri") or "", user_id=self._spec.get("user") or "",
                         status="", start_time=time.time(), end_time=None, lifecycle_stage=""
                     ),
                     RunData()
@@ -557,6 +561,7 @@ class DSLibrary(object):
         """
         Signals the end of the operation.
         """
+        self._run_id = None
         if self._mlflow_all:
             mlflow.end_run()
 
@@ -599,7 +604,7 @@ class DSLibrary(object):
 
         :returns:       In the specific case where dask is True, returns the list of generated files.
         """
-        use_mlflow = self._mlflow_all
+        use_mlflow = self._mlflow_all and self._run_id
         # map resource name using supplied specs
         uri, kwargs = self._xlt_resource(resource_name, _mode="outputs", **kwargs)
         file_extension = find_url_extension(uri)
