@@ -18,7 +18,7 @@ from pexpect import split_command_line
 
 import dslibrary
 from dslibrary import ENV_DSLIBRARY_TOKEN
-from dslibrary.front import DSLibraryException, ENV_DSLIBRARY_TARGET, ENV_DSLIBRARY_SPEC, METRICS_ALIAS
+from dslibrary.front import DSLibraryException, ENV_DSLIBRARY_TARGET, ENV_DSLIBRARY_SPEC, METRICS_ALIAS, THREAD_SPEC
 from dslibrary.metadata import Metadata
 
 
@@ -252,22 +252,16 @@ class ModelRunner(object):
             call_kwargs["dsl" if "dsl" in sig.parameters else "dslibrary"] = dsl
             retval = method(**call_kwargs)
         else:
-            # otherwise we assume method() calls dslibrary.instance()
-            # - this approach is not thread safe
-            # TODO is this approach even worth supporting???
             run_env = self.prepare_run_env(local_path=path, local=False)
             dsl = dslibrary
-            orig_env = {ENV_DSLIBRARY_TARGET: os.environ.get(ENV_DSLIBRARY_TARGET), ENV_DSLIBRARY_SPEC: os.environ.get(ENV_DSLIBRARY_SPEC)}
             try:
-                # store specification
-                for k, v in run_env.items():
-                    os.environ[k] = v or ""
+                # this specification will apply only for this thread, during this call
+                spec = json.loads(run_env[ENV_DSLIBRARY_SPEC])
+                THREAD_SPEC.value = spec
                 # the method makes calls to dslibrary, following rules set above
                 retval = method(**call_kwargs)
             finally:
-                # restore environment
-                for k, v in orig_env.items():
-                    os.environ[k] = v or ""
+                del THREAD_SPEC.value
         # we return captured data, in case there is any, and it replaces the method return value
         if hasattr(dsl, "_spec"):
             captured = dsl._spec.get("capture")
