@@ -26,6 +26,16 @@ class DSLibraryViaMMLibrary(DSLibrary):
         self._mm = _mm or mmlibrary
         super(DSLibraryViaMMLibrary, self).__init__(*args, **kwargs)
 
+    def _adjust_spec(self, spec: dict) -> dict:
+        # let 'mmlibrary' configure our defaults
+        dslibrary_config = self._find_method("dslibrary_config", mandatory=False)
+        if dslibrary_config:
+            cfg = dslibrary_config()
+            if cfg.get("mlflow_all"):
+                spec = dict(spec)
+                spec["mlflow"] = {"all": True}
+        return spec
+
     def get_metadata(self):
         return Metadata()
 
