@@ -35,9 +35,11 @@ class FileOpener(object):
         :return:        A stream, if the supplied arguments were supported, or None.
         """
         if path.startswith("https://") or path.startswith("http://") or path.startswith("ftp://"):
+            allowed = ("data", "timeout", "cafile", "cadefault", "context")
+            use_kwargs = {k: v for k, v in kwargs.items() if k in allowed}
             if mode == "rb":
                 request = urllib.request.Request(url=path, headers=kwargs.get("headers") or {})
-                return urllib.request.urlopen(request, **kwargs)
+                return urllib.request.urlopen(request, **use_kwargs)
             if mode == "r":
                 byte_stream = self.http_open(path, mode, **kwargs)
                 return io.TextIOWrapper(byte_stream)
@@ -47,8 +49,10 @@ class FileOpener(object):
                 #  - set any needed authentication headers in 'headers'
                 #  - path is URL plus any required arguments in the query string
                 request = urllib.request.Request(url=path, headers=kwargs.get("headers") or {}, method=kwargs.get("method", "POST"))
-                return write_stream_with_read_on_close(mode, r_mode='rb', on_close=lambda stream: urllib.request.urlopen(request, data=stream))
-            raise ValueError(f"Append mode is not supported for {path}")
+                if "data" in use_kwargs:
+                    use_kwargs.pop("data")
+                return write_stream_with_read_on_close(mode, r_mode='rb', on_close=lambda stream: urllib.request.urlopen(request, data=stream, **use_kwargs))
+            raise ValueError(f"Mode is not supported for {path}: {mode}")
 
     def uri_open(self, path: str, mode: str, **kwargs):
         """
