@@ -210,7 +210,7 @@ class TestRunMethod(unittest.TestCase):
         class Cursor(object):
             def __init__(self):
                 self.description = ("a", None), ("b", None)
-            def execute(self, sql):
+            def execute(self, sql, parameters=None):
                 log.append(sql)
             def __iter__(self):
                 return iter([(1, 2), (3, 4)])
@@ -288,5 +288,22 @@ class TestRunMethod(unittest.TestCase):
         metrics = outputs[METRICS_ALIAS]
         assert metrics == {'tot_before': 6, 'tot_after': 9}
 
+    def test_named_sql_engine(self):
+        """
+        An SQL engine can be referenced as a named input.
+        """
+        def my_model(dsl):
+            r = dsl.get_sql_connection("sql1")
+            self.assertEqual("CONNECTION", r)
+        runner = ModelRunner()
+        runner.set_input("sql1", uri="postgres://host/database", username="u", password="p")
+        def connect(uri, username, password, **k):
+            self.assertEqual(uri, "postgres://host/database")
+            self.assertEqual(username, "u")
+            self.assertEqual(password, "p")
+            return "CONNECTION"
+        with mock.patch("dslibrary.front.connect_to_database", connect):
+            runner.run_method(my_model)
+
     def tearDown(self) -> None:
         reset_env("test_run_method")
