@@ -4,6 +4,7 @@ import tempfile
 import zipfile
 import io
 import pandas
+import mock
 
 from dslibrary.front import DSLibraryException
 from dslibrary.transport.to_mmlibrary import DSLibraryViaMMLibrary
@@ -215,3 +216,25 @@ class TestToMMLibrary(unittest.TestCase):
         self.assertEqual(r.name, "x")
         self.assertEqual(r.value, 123)
         self.assertEqual(r.time, 1000000)
+
+    def test_cfg_mlflow_1(self):
+        class MyMM(object):
+            def dslibrary_config(self):
+                return {"mlflow_all": True}
+        dsl = DSLibraryViaMMLibrary(_mm=MyMM())
+        # verify configuration
+        self.assertEqual(True, dsl._mlflow_all)
+        self.assertEqual(True, dsl._mlflow_metrics)
+        # make sure metrics are sent to mlflow
+        metrics = {}
+        with mock.patch("mlflow.log_metric", lambda k, v, *a: metrics.__setitem__(k, v)):
+            dsl.log_metric("x", 123)
+        self.assertEqual({"x": 123}, metrics)
+
+    def test_cfg_mlflow_0(self):
+        class MyMM(object):
+            pass
+        dsl = DSLibraryViaMMLibrary(_mm=MyMM())
+        # verify configuration
+        assert not dsl._mlflow_all
+        assert not dsl._mlflow_metrics
